Documentation
¶
Overview ¶
Package oaktoken provides a secure random string factory that can be used for session or other types of tokens.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FastRandom ¶
FastRandom is inspired by Ketan Parmar's work:
- https://github.com/kpbird/golang_random_string/blob/master/main.go - https://kpbird.medium.com/golang-generate-fixed-size-random-string-dd6dbd5e63c0
Types ¶
type Factory ¶
func NewURLToken ¶
type Option ¶
type Option func(*options) error
func WithBodyCharacterSet ¶
func WithDefaultOptions ¶
func WithDefaultOptions() Option
func WithEdgeCharacterSet ¶
func WithTokenEdgeLength ¶
func WithTokenLength ¶
Click to show internal directories.
Click to hide internal directories.